==> quarkus-agroal-1.3.1.Final-sources.jar: io/quarkus/agroal/runtime/DataSourceJdbcRuntimeConfig$$accessor.java <==
package io.quarkus.agroal.runtime;
public final class DataSourceJdbcRuntimeConfig$$accessor {
    private DataSourceJdbcRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_url(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).url;
    }
    @SuppressWarnings("unchecked")
    public static void set_url(Object __instance, Object url) {
        ((DataSourceJdbcRuntimeConfig)__instance).url = (java.util.Optional<String>)url;
    }
    @SuppressWarnings("unchecked")
    public static Object get_initialSize(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).initialSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_initialSize(Object __instance, Object initialSize) {
        ((DataSourceJdbcRuntimeConfig)__instance).initialSize = (java.util.OptionalInt)initialSize;
    }
    @SuppressWarnings("unchecked")
    public static int get_minSize(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).minSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_minSize(Object __instance, int minSize) {
        ((DataSourceJdbcRuntimeConfig)__instance).minSize = minSize;
    }
    @SuppressWarnings("unchecked")
    public static int get_maxSize(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).maxSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxSize(Object __instance, int maxSize) {
        ((DataSourceJdbcRuntimeConfig)__instance).maxSize = maxSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_backgroundValidationInterval(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).backgroundValidationInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_backgroundValidationInterval(Object __instance, Object backgroundValidationInterval) {
        ((DataSourceJdbcRuntimeConfig)__instance).backgroundValidationInterval = (java.util.Optional<java.time.Duration>)backgroundValidationInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_acquisitionTimeout(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).acquisitionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_acquisitionTimeout(Object __instance, Object acquisitionTimeout) {
        ((DataSourceJdbcRuntimeConfig)__instance).acquisitionTimeout = (java.util.Optional<java.time.Duration>)acquisitionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_leakDetectionInterval(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).leakDetectionInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_leakDetectionInterval(Object __instance, Object leakDetectionInterval) {
        ((DataSourceJdbcRuntimeConfig)__instance).leakDetectionInterval = (java.util.Optional<java.time.Duration>)leakDetectionInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_idleRemovalInterval(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).idleRemovalInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_idleRemovalInterval(Object __instance, Object idleRemovalInterval) {
        ((DataSourceJdbcRuntimeConfig)__instance).idleRemovalInterval = (java.util.Optional<java.time.Duration>)idleRemovalInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxLifetime(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).maxLifetime;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxLifetime(Object __instance, Object maxLifetime) {
        ((DataSourceJdbcRuntimeConfig)__instance).maxLifetime = (java.util.Optional<java.time.Duration>)maxLifetime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_transactionIsolationLevel(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).transactionIsolationLevel;
    }
    @SuppressWarnings("unchecked")
    public static void set_transactionIsolationLevel(Object __instance, Object transactionIsolationLevel) {
        ((DataSourceJdbcRuntimeConfig)__instance).transactionIsolationLevel = (java.util.Optional<io.agroal.api.configuration.AgroalConnectionFactoryConfiguration.TransactionIsolation>)transactionIsolationLevel;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_detectStatementLeaks(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).detectStatementLeaks;
    }
    @SuppressWarnings("unchecked")
    public static void set_detectStatementLeaks(Object __instance, boolean detectStatementLeaks) {
        ((DataSourceJdbcRuntimeConfig)__instance).detectStatementLeaks = detectStatementLeaks;
    }
    @SuppressWarnings("unchecked")
    public static Object get_newConnectionSql(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).newConnectionSql;
    }
    @SuppressWarnings("unchecked")
    public static void set_newConnectionSql(Object __instance, Object newConnectionSql) {
        ((DataSourceJdbcRuntimeConfig)__instance).newConnectionSql = (java.util.Optional<String>)newConnectionSql;
    }
    @SuppressWarnings("unchecked")
    public static Object get_validationQuerySql(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).validationQuerySql;
    }
    @SuppressWarnings("unchecked")
    public static void set_validationQuerySql(Object __instance, Object validationQuerySql) {
        ((DataSourceJdbcRuntimeConfig)__instance).validationQuerySql = (java.util.Optional<String>)validationQuerySql;
    }
    public static Object construct() {
        return new DataSourceJdbcRuntimeConfig();
    }
}

==> quarkus-agroal-1.5.2.Final-sources.jar: io/quarkus/agroal/runtime/DataSourceJdbcRuntimeConfig$$accessor.java <==
package io.quarkus.agroal.runtime;
public final class DataSourceJdbcRuntimeConfig$$accessor {
    private DataSourceJdbcRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_url(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).url;
    }
    @SuppressWarnings("unchecked")
    public static void set_url(Object __instance, Object url) {
        ((DataSourceJdbcRuntimeConfig)__instance).url = (java.util.Optional<String>)url;
    }
    @SuppressWarnings("unchecked")
    public static Object get_initialSize(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).initialSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_initialSize(Object __instance, Object initialSize) {
        ((DataSourceJdbcRuntimeConfig)__instance).initialSize = (java.util.OptionalInt)initialSize;
    }
    @SuppressWarnings("unchecked")
    public static int get_minSize(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).minSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_minSize(Object __instance, int minSize) {
        ((DataSourceJdbcRuntimeConfig)__instance).minSize = minSize;
    }
    @SuppressWarnings("unchecked")
    public static int get_maxSize(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).maxSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxSize(Object __instance, int maxSize) {
        ((DataSourceJdbcRuntimeConfig)__instance).maxSize = maxSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_backgroundValidationInterval(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).backgroundValidationInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_backgroundValidationInterval(Object __instance, Object backgroundValidationInterval) {
        ((DataSourceJdbcRuntimeConfig)__instance).backgroundValidationInterval = (java.util.Optional<java.time.Duration>)backgroundValidationInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_acquisitionTimeout(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).acquisitionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_acquisitionTimeout(Object __instance, Object acquisitionTimeout) {
        ((DataSourceJdbcRuntimeConfig)__instance).acquisitionTimeout = (java.util.Optional<java.time.Duration>)acquisitionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_leakDetectionInterval(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).leakDetectionInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_leakDetectionInterval(Object __instance, Object leakDetectionInterval) {
        ((DataSourceJdbcRuntimeConfig)__instance).leakDetectionInterval = (java.util.Optional<java.time.Duration>)leakDetectionInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_idleRemovalInterval(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).idleRemovalInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_idleRemovalInterval(Object __instance, Object idleRemovalInterval) {
        ((DataSourceJdbcRuntimeConfig)__instance).idleRemovalInterval = (java.util.Optional<java.time.Duration>)idleRemovalInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxLifetime(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).maxLifetime;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxLifetime(Object __instance, Object maxLifetime) {
        ((DataSourceJdbcRuntimeConfig)__instance).maxLifetime = (java.util.Optional<java.time.Duration>)maxLifetime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_transactionIsolationLevel(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).transactionIsolationLevel;
    }
    @SuppressWarnings("unchecked")
    public static void set_transactionIsolationLevel(Object __instance, Object transactionIsolationLevel) {
        ((DataSourceJdbcRuntimeConfig)__instance).transactionIsolationLevel = (java.util.Optional<io.agroal.api.configuration.AgroalConnectionFactoryConfiguration.TransactionIsolation>)transactionIsolationLevel;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_detectStatementLeaks(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).detectStatementLeaks;
    }
    @SuppressWarnings("unchecked")
    public static void set_detectStatementLeaks(Object __instance, boolean detectStatementLeaks) {
        ((DataSourceJdbcRuntimeConfig)__instance).detectStatementLeaks = detectStatementLeaks;
    }
    @SuppressWarnings("unchecked")
    public static Object get_newConnectionSql(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).newConnectionSql;
    }
    @SuppressWarnings("unchecked")
    public static void set_newConnectionSql(Object __instance, Object newConnectionSql) {
        ((DataSourceJdbcRuntimeConfig)__instance).newConnectionSql = (java.util.Optional<String>)newConnectionSql;
    }
    @SuppressWarnings("unchecked")
    public static Object get_validationQuerySql(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).validationQuerySql;
    }
    @SuppressWarnings("unchecked")
    public static void set_validationQuerySql(Object __instance, Object validationQuerySql) {
        ((DataSourceJdbcRuntimeConfig)__instance).validationQuerySql = (java.util.Optional<String>)validationQuerySql;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_poolingEnabled(Object __instance) {
        return ((DataSourceJdbcRuntimeConfig)__instance).poolingEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_poolingEnabled(Object __instance, boolean poolingEnabled) {
        ((DataSourceJdbcRuntimeConfig)__instance).poolingEnabled = poolingEnabled;
    }
    public static Object construct() {
        return new DataSourceJdbcRuntimeConfig();
    }
}
